@@ -9,6 +9,7 @@ Usage::
         Client,
         DescribeResourceCollectionHealthPaginator,
         DevopsGuruClient,
+        GetCostEstimationPaginator,
         GetResourceCollectionPaginator,
         ListAnomaliesForInsightPaginator,
         ListEventsPaginator,
@@ -24,6 +25,7 @@ Usage::
     session_client: DevopsGuruClient = session.client("devops-guru")
 
     describe_resource_collection_health_paginator: DescribeResourceCollectionHealthPaginator = client.get_paginator("describe_resource_collection_health")
+    get_cost_estimation_paginator: GetCostEstimationPaginator = client.get_paginator("get_cost_estimation")
     get_resource_collection_paginator: GetResourceCollectionPaginator = client.get_paginator("get_resource_collection")
     list_anomalies_for_insight_paginator: ListAnomaliesForInsightPaginator = client.get_paginator("list_anomalies_for_insight")
     list_events_paginator: ListEventsPaginator = client.get_paginator("list_events")
@@ -36,6 +38,7 @@ Usage::
 from mypy_boto3_devops_guru.client import DevopsGuruClient
 from mypy_boto3_devops_guru.paginator import (
     DescribeResourceCollectionHealthPaginator,
+    GetCostEstimationPaginator,
     GetResourceCollectionPaginator,
     ListAnomaliesForInsightPaginator,
     ListEventsPaginator,
@@ -52,6 +55,7 @@ __all__ = (
     "Client",
     "DescribeResourceCollectionHealthPaginator",
     "DevopsGuruClient",
+    "GetCostEstimationPaginator",
     "GetResourceCollectionPaginator",
     "ListAnomaliesForInsightPaginator",
     "ListEventsPaginator",
